==> dde-session-shell_5.4.13.orig.tar.xz: dde-session-shell-5.4.13/translations/dde-session-shell_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>ContentWidget</name>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="357"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador encerre, e forçar o encerramento pode causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="358"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="363"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="367"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="371"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="375"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Para fechar o programa, clique em &quot;Cancelar&quot; e depois feche o programa.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="362"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador reinicie, e forçar o reinício pode causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="366"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador suspenda, e forçar a suspensão pode causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="370"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador hiberne, e forçar a hibernação pode causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="374"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de terminar sessão, e forçar a saída pode causar perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="391"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="435"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="460"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="614"/>
        <source>Shut down</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="394"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="437"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="463"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="617"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="397"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="620"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="399"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="623"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="401"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="466"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="629"/>
        <source>Log out</source>
        <translation>Terminar sessão</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="461"/>
        <source>Are you sure you want to shut down?</source>
        <translation>Tem a certeza que deseja encerrar?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="464"/>
        <source>Are you sure you want to reboot?</source>
        <translation>Tem a certeza que deseja reiniciar?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="467"/>
        <source>Are you sure you want to log out?</source>
        <translation>Tem a certeza que deseja terminar a sessão?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="626"/>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="632"/>
        <source>Switch user</source>
        <translation>Mudar de utilizador</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="637"/>
        <source>Switch system</source>
        <translation>Mudar de sistema</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="329"/>
        <source>Wrong Password</source>
        <translation>Palavra-passe incorreta</translation>
    </message>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="333"/>
        <source>The account or password is not correct. Please enter again.</source>
        <translation>A conta ou a palavra-passe não estão corretas. Por favor, insira novamente.</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="90"/>
        <location filename="../src/widgets/inhibitwarnview.cpp" line="90"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="405"/>
        <source>Lock Screen</source>
        <translation>Bloquear ecrã</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="409"/>
        <source>Failed to lock screen</source>
        <translation>O bloqueio do ecrã falhou</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="291"/>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>A verificação da impressão digital expirou, insira manualmente a sua palavra-passe</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="309"/>
        <source>Failed to match fingerprint</source>
        <translation>A impressão digital não coincide</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="339"/>
        <source>Wrong Password</source>
        <translation>Palavra-passe incorreta</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="45"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="130"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="133"/>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Os utilizadores acima ainda estão autenticados e os dados serão perdidos se encerrar. Tem a certeza que deseja encerrar?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="134"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="137"/>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Os utilizadores acima ainda estão autenticados e os dados serão perdidos se reiniciar. Tem a certeza que deseja reiniciar?</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
        <source>Shut down</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="172"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="178"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="33"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="184"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="190"/>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="196"/>
        <source>Log out</source>
        <translation>Terminar sessão</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="202"/>
        <source>Switch user</source>
        <translation>Trocar de utilizador</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="210"/>
        <source>Switch system</source>
        <translation>Mudar de sistema</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
        <location filename="../src/widgets/systemmonitor.cpp" line="45"/>
        <source>Start system monitor</source>
        <translation>Iniciar monitor do sistema</translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="193"/>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="197"/>
        <source>Account</source>
        <translation>Conta</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="239"/>
        <source>Please enter the account</source>
        <translation>Por favor, introduza a conta</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="246"/>
        <source>Please enter the password</source>
        <translation>Por favor, introduza a palavra-passe</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/session-widgets/userloginwidget.cpp" line="338"/>
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Tentar novamente %n minuto(s) mais tarde</numerusform><numerusform>Tentar novamente %n minuto(s) mais tarde</numerusform></translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="149"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de encerrar, e forçar o encerramento pode causar perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="150"/>
        <location filename="../src/widgets/warningcontent.cpp" line="155"/>
        <location filename="../src/widgets/warningcontent.cpp" line="159"/>
        <location filename="../src/widgets/warningcontent.cpp" line="163"/>
        <location filename="../src/widgets/warningcontent.cpp" line="167"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Para fechar o programa, clique em Cancelar e depois feche o programa.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="154"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de reiniciar, e forçar o reinício pode causar perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="158"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador entre em suspensão, e forçar a suspensão pode causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="162"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador entre em hibernação, e forçar a hibernação pode causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="166"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de terminar sessão, e forçar a saída pode causar perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="182"/>
        <location filename="../src/widgets/warningcontent.cpp" line="235"/>
        <location filename="../src/widgets/warningcontent.cpp" line="267"/>
        <source>Shut down</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="185"/>
        <location filename="../src/widgets/warningcontent.cpp" line="237"/>
        <location filename="../src/widgets/warningcontent.cpp" line="270"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="188"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="190"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="192"/>
        <location filename="../src/widgets/warningcontent.cpp" line="273"/>
        <source>Log out</source>
        <translation>Terminar sessão</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="268"/>
        <source>Are you sure you want to shut down?</source>
        <translation>Tem a certeza que deseja encerrar?</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="271"/>
        <source>Are you sure you want to reboot?</source>
        <translation>Tem a certeza que deseja reiniciar?</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="274"/>
        <source>Are you sure you want to log out?</source>
        <translation>Tem a certeza que deseja terminar a sessão?</translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.14.orig.tar.xz: dde-session-shell-5.5.14/translations/dde-session-shell_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifique a impressão digital</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>A verificação falhou, %n tentativa restante</numerusform><numerusform>A verificação falhou, %n tentativas restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Impressão digital bloqueada, utilize a palavra-passe</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Tentar novamente %n minuto mais tarde</numerusform><numerusform>Tentar novamente %n minutos mais tarde</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>A verificação falhou, %n tentativa restante</numerusform><numerusform>A verificação falhou, %n tentativas restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Palavra-passe incorreta</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Tentar novamente %n minuto mais tarde</numerusform><numerusform>Tentar novamente %n minutos mais tarde</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Tentar novamente 1 minuto depois</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Tentar novamente %n minuto depois</numerusform><numerusform>Tentar novamente %n minutos depois</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>A verificação falhou, %n tentativa restante</numerusform><numerusform>A verificação falhou, %n tentativas restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN incorreto</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey é necessária</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Introduza o seu PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Tentar novamente %n minuto mais tarde</numerusform><numerusform>Tentar novamente %n minutos mais tarde</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthenticationModule</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>A verificação falhou, %d tentativa restante</numerusform><numerusform>A verificação falhou, %d tentativas restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou, resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Palavra-passe incorreta</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN incorreto</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey é necessária</translation>
    </message>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifique a impressão digital</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Introduza o seu PIN</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Impressão digital bloqueada, utilize a palavra-passe</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Tentar novamente 1 minuto depois</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Tentar novamente %n minuto depois</numerusform><numerusform>Tentar novamente %n minutos depois</numerusform></translation>
    </message>
</context>
<context>
    <name>ContentWidget</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador encerre, e forçar o encerramento pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Para fechar o programa, clique em &quot;Cancelar&quot; e depois feche o programa.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador reinicie, e forçar o reinício pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador suspenda, e forçar a suspensão pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador hiberne, e forçar a hibernação pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de terminar sessão, e forçar a saída pode causar perda de dados.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Terminar sessão</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Tem a certeza que deseja encerrar?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Tem a certeza que deseja reiniciar?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Tem a certeza que deseja terminar a sessão?</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Mudar de utilizador</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Mudar de sistema</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <source>Wrong account</source>
        <translation>Conta incorreta</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Palavra-passe incorreta</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Bloquear ecrã</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>O bloqueio do ecrã falhou</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>A verificação da impressão digital expirou, insira manualmente a sua palavra-passe</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>A impressão digital não coincide</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Os utilizadores acima ainda estão autenticados e os dados serão perdidos se encerrar. Tem a certeza que deseja encerrar?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Os utilizadores acima ainda estão autenticados e os dados serão perdidos se reiniciar. Tem a certeza que deseja reiniciar?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Terminar sessão</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Trocar de utilizador</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Mudar de sistema</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Iniciar monitor do sistema</translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <source>Account</source>
        <translation>Conta</translation>
    </message>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifique a impressão digital</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>A palavra-passe expirará dentro de %n dia. Altere-a atempadamente</numerusform><numerusform>A palavra-passe expirará dentro de %n dias. Altere-a atempadamente</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>A palavra-passe expirou, altere-a</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de encerrar. Forçar o encerramento pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Para fechar o programa, clique em Cancelar e depois feche o programa.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de reiniciar. Forçar o reinício pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador entre em suspensão. Forçar a suspensão pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Os programas estão a impedir que o computador entre em hibernação. Forçar a hibernação pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Os programas estão a impedir o computador de terminar sessão. Forçar o término da sessão pode causar a perda de dados.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Terminar sessão</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Tem a certeza que deseja encerrar?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Tem a certeza que deseja reiniciar?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Tem a certeza que deseja terminar a sessão?</translation>
    </message>
</context>
</TS>
